@@ -358,6 +358,25 @@ img[loading="lazy"] {{
   animation: heroFloat 20s ease-in-out infinite;
 }}
 
+.hero-overlay {{
+  position: relative;
+  overflow: hidden;
+}}
+
+.hero-overlay .overlay {{
+  position: absolute;
+  inset: 0;
+  background: linear-gradient(200deg, rgba(17, 24, 39, 0.65) 0%, rgba(17, 24, 39, 0.35) 55%, rgba(17, 24, 39, 0.08) 100%);
+  mix-blend-mode: multiply;
+  backdrop-filter: blur(6px);
+  z-index: 0;
+}}
+
+.hero-overlay .container {{
+  position: relative;
+  z-index: 1;
+}}
+
 @keyframes heroFloat {{
   0%, 100% {{ transform: rotate(0deg) scale(1); }}
   33% {{ transform: rotate(10deg) scale(1.1); }}
@@ -1110,6 +1129,85 @@ img[loading="lazy"] {{
   line-height: var(--line-height-relaxed);
 }}
 
+.shadow-soft {{
+  background: var(--white);
+  border-radius: var(--radius-xl);
+  box-shadow: 0 22px 45px -28px rgba(17, 24, 39, 0.4);
+  transition: transform var(--duration-base) var(--ease-out), box-shadow var(--duration-base) var(--ease-out);
+}}
+
+.shadow-soft:hover {{
+  transform: translateY(-6px);
+  box-shadow: 0 30px 55px -26px rgba(17, 24, 39, 0.45);
+}}
+
+.icon-badge {{
+  display: inline-flex;
+  width: 3rem;
+  height: 3rem;
+  align-items: center;
+  justify-content: center;
+  border-radius: var(--radius-full);
+  color: var(--white);
+  box-shadow: var(--shadow-md);
+  font-size: 1.35rem;
+}}
+
+.border-gradient {{
+  border-radius: var(--radius-xl);
+  border: 1px solid transparent;
+  background:
+    linear-gradient(var(--white), var(--white)) padding-box,
+    linear-gradient(135deg, rgba(var(--primary-rgb), 0.28), rgba(255, 255, 255, 0.08)) border-box;
+}}
+
+.membership-card {{
+  background: rgba(255, 255, 255, 0.94);
+  border-radius: var(--radius-xl);
+  border: 1px solid rgba(148, 163, 184, 0.18);
+  transition: transform var(--duration-base) var(--ease-out), box-shadow var(--duration-base) var(--ease-out);
+  display: flex;
+  flex-direction: column;
+  gap: var(--space-sm);
+  color: var(--gray-800);
+}}
+
+.membership-card:hover {{
+  transform: translateY(-6px);
+  box-shadow: var(--shadow-2xl);
+}}
+
+.membership-card.highlight {{
+  background: linear-gradient(135deg, rgba(30, 58, 138, 0.95) 0%, rgba(67, 56, 202, 0.95) 35%, rgba(245, 158, 11, 0.95) 100%);
+  color: var(--white);
+}}
+
+.membership-card.highlight p,
+.membership-card.highlight li {{
+  color: rgba(255, 255, 255, 0.86);
+}}
+
+.testimonial-card {{
+  border-radius: var(--radius-xl);
+  border: 1px solid rgba(148, 163, 184, 0.25);
+  backdrop-filter: blur(10px);
+  -webkit-backdrop-filter: blur(10px);
+  background: rgba(255, 255, 255, 0.9);
+  box-shadow: var(--shadow-md);
+  transition: transform var(--duration-base) var(--ease-out), box-shadow var(--duration-base) var(--ease-out);
+}}
+
+.testimonial-card:hover {{
+  transform: translateY(-4px);
+  box-shadow: var(--shadow-2xl);
+}}
+
+.avatar {{
+  width: 64px;
+  height: 64px;
+  object-fit: cover;
+}}
+
 /* ==================== CTA 区域 ==================== */
 .cta {{
   background: var(--gradient-primary);
@@ -1380,6 +1478,56 @@ img[loading="lazy"] {{
   border-radius: var(--radius-xl);
 }}
 
+.btn-gradient {{
+  background: var(--gradient-primary);
+  color: var(--white);
+  border: none;
+  box-shadow: var(--shadow-lg);
+}}
+
+.btn-gradient:hover {{
+  transform: translateY(-2px);
+  box-shadow: 0 18px 45px -12px rgba(var(--primary-rgb), 0.45);
+  opacity: 0.95;
+}}
+
+.btn-dark-gradient {{
+  background: linear-gradient(135deg, rgba(17, 24, 39, 0.95) 0%, rgba(55, 65, 81, 0.95) 100%);
+  color: var(--white);
+  border: none;
+  box-shadow: var(--shadow-lg);
+}}
+
+.btn-dark-gradient:hover {{
+  transform: translateY(-2px);
+  box-shadow: 0 20px 50px -15px rgba(17, 24, 39, 0.55);
+}}
+
+.btn-outline-primary {{
+  color: var(--primary);
+  border: 2px solid var(--primary);
+  background: transparent;
+}}
+
+.btn-outline-primary:hover {{
+  background: var(--primary);
+  color: var(--white);
+  box-shadow: var(--shadow-md);
+}}
+
+.btn-outline-light {{
+  color: var(--white);
+  border: 2px solid rgba(255, 255, 255, 0.6);
+  background: transparent;
+}}
+
+.btn-outline-light:hover {{
+  background: rgba(255, 255, 255, 0.15);
+  color: var(--white);
+  border-color: rgba(255, 255, 255, 0.9);
+  transform: translateY(-2px);
+}}
+
 /* 按钮涟漪效果 */
 .btn::before {{
   content: '';
