@@ -504,7 +504,7 @@ async def execute_plan(
 
     参数详细说明：
     - plan_id: 计划的唯一标识符
-        由 plan_site 工具返回的计划ID，用于从缓存或文件系统中查找对应的执行计划。
+        由 create_simple_site 工具返回的计划ID，用于从缓存或文件系统中查找对应的执行计划。
         例如："a1b2c3d4e5f6..." 这样的32位十六进制字符串。
 
     - project_root: 网站文件生成的目标目录路径（可选）
@@ -518,13 +518,11 @@ async def execute_plan(
         如果未指定：自动在 ~/.mcp/make_web/progress_logs 目录创建时间戳命名的日志文件（可通过环境变量覆盖）
         路径可以是绝对路径或相对于 project_root 的相对路径
 
-        注意：进度日志始终会被创建，以便使用 get_progress 工具查询任务进度。
-
     执行流程：
-    - 任务始终在后台异步执行，立即返回 job_id 和 progress_log 路径
-    - 使用 get_progress(job_id=..., limit=...) 可以实时查询执行状态和进度
+    - 任务在后台异步执行，立即返回 job_id 和 progress_log 路径
+    - 任务完成后，系统会自动推送通知给用户，包含执行报告、生成文件列表和上传结果
     - 系统会自动记录详细的执行步骤和结果到进度日志文件
-    - 执行完成后可以获取完整的执行报告、生成文件列表，以及自动上传结果
+    - 如需实时了解任务进展或调试，可使用 get_progress(job_id=...) 工具手动查询状态
     """
     try:
         # 如果没有提供project_root，尝试从缓存中获取
@@ -547,19 +545,21 @@ async def execute_plan(
                                 break
                         except Exception:
                             pass
-                
+
                 if not project_root:
                     # 使用默认根目录，但不添加子目录
                     project_root = None
-        
+
         # 从计划中获取项目名称（如果有）
         project_name = None
         if plan_id:
             cached_plan = _PLAN_CACHE_BY_ID.get(plan_id)
             if cached_plan:
                 # 尝试从缓存中获取项目名称
-                project_name = cached_plan.get("site_title") or cached_plan.get("project_name")
-        
+                project_name = cached_plan.get("site_title") or cached_plan.get(
+                    "project_name"
+                )
+
         project_dir = _resolve_project_directory(project_root, project_name)
 
         # 进度日志始终启用
@@ -857,7 +857,7 @@ async def create_simple_site(
     使用流程：
     1. 调用此工具生成计划，获得 plan_id
     2. 使用 plan_id 调用 execute_plan 执行构建
-    3. 使用 plan_id 调用 get_progress 查询进度
+    3. 构建完成后会自动推送通知给用户，包含项目文件和访问链接
 
     💡 使用提示：
     如果你有地图查询结果、API数据等，请将完整信息传递给 context_content 参数，
@@ -1174,8 +1174,8 @@ async def get_progress(
                 "model",
                 "upload_status",
                 "upload_url",
-                 "web_url",
-                 "deployment_env",
+                "web_url",
+                "deployment_env",
                 "upload_completed_at",
                 "uploaded_directory",
             ]
